# nonebot-plugin-mediawiki
适用于 nonebot2 的 MediaWiki 查询插件

本项目是 [Flandre](https://github.com/KoishiStudio/Flandre) 的一部分，经简单修改成为独立插件发布

使用方法位于插件源代码内，也可以使用 [nonebot-plugin-help](https://github.com/XZhouQD/nonebot-plugin-help) 在运行时查询帮助
